Installation
============

Install by running the following:

  python setup.py install


Configuration
=============

Make sure you enable the extension after you've completed the installation. You will also
need the Mopidy-Stream extension enabled - it's bundled with Mopidy, so unless you disabled it
it should be available.

You may change prefered quality in your Mopidy configuration file. An example configuration is
included in the ext.conf file.

If you have an AudioAddict premium account, fill in your API key. This will allow you to use the 
higher quality streams as usual on all the network sites.

For quality you can pick between 40k, 64k, 128k and 320k


Project resources
=================

Bugs, feedback and patches are always welcome at https://github.com/nilicule/mopidy-audioaddict
